# -*- coding: utf-8 -*-

import configparser
import os
import urllib.parse

config = configparser.ConfigParser()
config.read('/etc/spoc/spoc.conf')

def get_repo_auth(config):
    username = config.get('repo', 'username', fallback='')
    password = config.get('repo', 'password', fallback='')
    if not username and not password:
        return None
    return (username, password)

NETWORK_INTERFACE = config.get('general', 'network-interface', fallback='spocbr0')

DATA_DIR =          config.get('general', 'data-dir', fallback='/var/lib/spoc')
APPS_DIR =          os.path.join(DATA_DIR, 'apps')
CONTAINERS_DIR =    os.path.join(DATA_DIR, 'containers')
LAYERS_DIR =        os.path.join(DATA_DIR, 'layers')
VOLUME_DIR =        os.path.join(DATA_DIR, 'volumes')
HOSTS_FILE =        os.path.join(DATA_DIR, 'hosts')
REPO_FILE =         os.path.join(DATA_DIR, 'repository.json')
LOG_DIR =           config.get('general', 'log-dir', fallback='/var/log/spoc')
LOCK_FILE =         '/run/lock/spoc.lock'

PUB_DIR =           config.get('publish', 'publish-dir', fallback=os.path.join(DATA_DIR, 'publish'))
PUB_LAYERS_DIR =    os.path.join(PUB_DIR, 'layers')
PUB_APPS_DIR =      os.path.join(PUB_DIR, 'apps')
PUB_PACKAGES_FILE = os.path.join(PUB_DIR, 'packages.json')
PUB_SIG_FILE =      os.path.join(PUB_DIR, 'packages.sig')
PUB_PRIVKEY_FILE =  config.get('publish', 'signing-key', fallback='/etc/spoc/publish.key')

REPO_URL =          config.get('repo', 'url', fallback='https://localhost')
REPO_PACKAGES_URL = urllib.parse.urljoin(REPO_URL, 'packages.json')
REPO_SIG_URL =      urllib.parse.urljoin(REPO_URL, 'packages.sig')
REPO_AUTH =         get_repo_auth(config)
REPO_PUBKEY =       config.get('repo', 'public-key', fallback='')
